.. MICE documentation master file, created by
   sphinx-quickstart on Sun Sep 26 11:42:21 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to MICE's documentation!
================================

This is the documentation of **MICE** version |release| released |today|.

.. toctree::
   :maxdepth: 2
   :caption: Contents:


   intro.rst
   setting_up.rst
   usage/index.rst
   modules.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
